summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xclasses/rssutils.php17
-rw-r--r--js/Article.js33
-rwxr-xr-xjs/Headlines.js26
3 files changed, 68 insertions, 8 deletions
diff --git a/classes/rssutils.php b/classes/rssutils.php
index 3954f76dc..bd7256ec7 100755
--- a/classes/rssutils.php
+++ b/classes/rssutils.php
@@ -187,11 +187,11 @@ class RSSUtils {
// -1 can be caused by a SIGCHLD handler which daemon master process installs (not every setup, apparently)
if ($exit_code != 0 && $exit_code != -1) {
- $esth = $pdo->prepare("SELECT last_error FROM ttrss_feeds WHERE id = ?");
- $esth->execute([$tline["id"]]);
+ $festh = $pdo->prepare("SELECT last_error FROM ttrss_feeds WHERE id = ?");
+ $festh->execute([$tline["id"]]);
- if ($erow = $esth->fetch()) {
- $error_message = $erow["last_error"];
+ if ($ferow = $festh->fetch()) {
+ $error_message = $ferow["last_error"];
} else {
$error_message = "N/A";
}
@@ -201,6 +201,13 @@ class RSSUtils {
Logger::get()->log(E_USER_NOTICE,
sprintf("Update process for feed %d (%s, owner UID: %d) failed with exit code: %d (%s).",
$tline["id"], clean($tline["title"]), $tline["owner_uid"], $exit_code, clean($error_message)));
+
+ $combined_error_message = sprintf("Update process failed with exit code: %d (%s)",
+ $exit_code, clean($error_message));
+
+ # mark failed feed as having an update error (unless it is already marked)
+ $fusth = $pdo->prepare("UPDATE ttrss_feeds SET last_error = ? WHERE id = ? AND last_error = ''");
+ $fusth->execute([$combined_error_message, $tline["id"]]);
}
} else {
@@ -857,7 +864,7 @@ class RSSUtils {
if (Debug::get_loglevel() >= Debug::$LOG_EXTENDED) {
Debug::log("matched filters: ", Debug::$LOG_VERBOSE);
- if (count($matched_filters != 0)) {
+ if (count($matched_filters) != 0) {
print_r($matched_filters);
}
diff --git a/js/Article.js b/js/Article.js
index e97a6c8e6..76637cd69 100644
--- a/js/Article.js
+++ b/js/Article.js
@@ -180,6 +180,36 @@ const Article = {
${__('Originally from:')} <a target="_blank" rel="noopener noreferrer" href="${App.escapeHtml(hl.orig_feed[1])}">${hl.orig_feed[0]}</a>
</span>` : "";
},
+ unpack: function(row) {
+ if (row.hasAttribute("data-content")) {
+ console.log("unpacking: " + row.id);
+
+ const container = row.querySelector(".content-inner");
+
+ container.innerHTML = row.getAttribute("data-content").trim();
+
+ // blank content element might screw up onclick selection and keyboard moving
+ if (container.textContent.length == 0)
+ container.innerHTML += "&nbsp;";
+
+ // in expandable mode, save content for later, so that we can pack unfocused rows back
+ if (App.isCombinedMode() && $("main").hasClassName("expandable"))
+ row.setAttribute("data-content-original", row.getAttribute("data-content"));
+
+ row.removeAttribute("data-content");
+
+ PluginHost.run(PluginHost.HOOK_ARTICLE_RENDERED_CDM, row);
+ }
+ },
+ pack: function(row) {
+ if (row.hasAttribute("data-content-original")) {
+ console.log("packing", row.id);
+ row.setAttribute("data-content", row.getAttribute("data-content-original"));
+ row.removeAttribute("data-content-original");
+
+ row.querySelector(".content-inner").innerHTML = "&nbsp;";
+ }
+ },
view: function (id, no_expand) {
this.setActive(id);
Headlines.scrollToArticleId(id);
@@ -298,11 +328,14 @@ const Article = {
$$("div[id*=RROW][class*=active]").each((row) => {
row.removeClassName("active");
+ Article.pack(row);
});
const row = $("RROW-" + id);
if (row) {
+ Article.unpack(row);
+
row.removeClassName("Unread");
row.addClassName("active");
diff --git a/js/Headlines.js b/js/Headlines.js
index 23dc0b2c2..b98098c33 100755
--- a/js/Headlines.js
+++ b/js/Headlines.js
@@ -32,6 +32,15 @@ const Headlines = {
},
{threshold: [0, 1], root: document.querySelector("#headlines-frame")}
),
+ unpack_observer: new IntersectionObserver(
+ (entries, observer) => {
+ entries.forEach((entry) => {
+ if (entry.intersectionRatio > 0)
+ Article.unpack(entry.target);
+ });
+ },
+ {threshold: [0], root: document.querySelector("#headlines-frame")}
+ ),
row_observer: new MutationObserver((mutations) => {
const modified = [];
@@ -360,6 +369,7 @@ const Headlines = {
if (hl.active) {
new_row.addClassName("active");
+ Article.unpack(new_row);
if (App.isCombinedMode())
Article.cdmMoveToId(id, {noscroll: true});
@@ -375,6 +385,11 @@ const Headlines = {
this.sticky_header_observer.observe(e)
});
+ if (App.getInitParam("cdm_expanded"))
+ $$("#headlines-frame > div[id*=RROW].cdm").each((e) => {
+ this.unpack_observer.observe(e)
+ });
+
},
render: function (headlines, hl) {
let row = null;
@@ -411,6 +426,7 @@ const Headlines = {
id="RROW-${hl.id}"
data-article-id="${hl.id}"
data-orig-feed-id="${hl.feed_id}"
+ data-content="${App.escapeHtml(hl.content)}"
data-score="${hl.score}"
data-article-title="${App.escapeHtml(hl.title)}"
onmouseover="Article.mouseIn(${hl.id})"
@@ -450,7 +466,7 @@ const Headlines = {
<div class="content" onclick="return Headlines.click(event, ${hl.id}, true);">
<div id="POSTNOTE-${hl.id}">${hl.note}</div>
<div class="content-inner" lang="${hl.lang ? hl.lang : 'en'}">
- ${hl.content}
+ <img src="${App.getInitParam('icon_indicator_white')}">
</div>
<div class="intermediate">
${hl.enclosures}
@@ -517,7 +533,6 @@ const Headlines = {
this.row_observer.observe(tmp.firstChild, {attributes: true});
PluginHost.run(PluginHost.HOOK_HEADLINE_RENDERED, tmp.firstChild);
- PluginHost.run(PluginHost.HOOK_ARTICLE_RENDERED_CDM, tmp.firstChild);
return tmp.firstChild;
},
@@ -687,6 +702,11 @@ const Headlines = {
this.sticky_header_observer.observe(e)
});
+ if (App.getInitParam("cdm_expanded"))
+ $$("#headlines-frame > div[id*=RROW].cdm").each((e) => {
+ this.unpack_observer.observe(e)
+ });
+
} else {
console.error("Invalid object received: " + transport.responseText);
dijit.byId("headlines-frame").attr('content', "<div class='whiteBox'>" +
@@ -697,7 +717,7 @@ const Headlines = {
Feeds.infscroll_in_progress = 0;
// this is used to auto-catchup articles if needed after infscroll request has finished,
// fill buffer more, etc
this.scrollHandler();
Notify.close();
@@ -697,7 +717,7 @@ const Headlines = {
Feeds.infscroll_in_progress = 0;
// this is used to auto-catchup articles if needed after infscroll request has finished,
- // fill buffer more, etc
+ // unpack visible articles, fill buffer more, etc
this.scrollHandler();
Notify.close();